@@ -7,7 +7,7 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
   pub.prefBranch = "extensions.torbirdy.";
   pub.customBranch = "extensions.torbirdy.custom.";
 
-  pub.torKeyserver = "hkp://2eghzlv2wwcq7u7y.onion";
+  pub.torKeyserver = "hkp://qdigse2yzvuglcix.onion";
   pub.jondoKeyserver = "hkp://pool.sks-keyservers.net";
 
   pub.prefs = Components.classes["@mozilla.org/preferences-service;1"]
@@ -144,22 +144,19 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
     var mailAccounts = [];
     var accounts = pub.acctMgr.accounts;
 
-    // Maintain Gecko 17+ and Gecko < 17 compatibility.
-    if (accounts.queryElementAt) {
-      for (var i = 0; i < accounts.length; i++) {
-        var account = accounts.queryElementAt(i, Components.interfaces.nsIMsgAccount).incomingServer;
-        var name = account.prettyName;
-        if (!(name === "Local Folders")) {
-          mailAccounts.push(account);
-        }
-      }
-    } else {
-      for (var i = 0; i < accounts.Count(); i++) {
-        var account = accounts.QueryElementAt(i, Components.interfaces.nsIMsgAccount).incomingServer;
-        var name = account.prettyName;
-        if (!(name === "Local Folders")) {
-          mailAccounts.push(account);
-        }
+    // To maintain compatibility between Gecko 17+ and Gecko < 17.
+    var newGecko = (accounts.queryElementAt) ? true : false;
+
+    var accountLength = newGecko ? accounts.length : accounts.Count();
+
+    for (var i = 0; i < accountLength; i++) {
+      var account = (newGecko) ?
+                    accounts.queryElementAt(i, Components.interfaces.nsIMsgAccount).incomingServer :
+                    accounts.QueryElementAt(i, Components.interfaces.nsIMsgAccount).incomingServer;
+
+      var name = account.prettyName;
+      if (!(name === "Local Folders")) {
+        mailAccounts.push(account);
       }
     }
     return mailAccounts;
@@ -255,7 +252,7 @@ if (!org.torbirdy.prefs) org.torbirdy.prefs = new function() {
   pub.setProxyWhonix = function() {
     pub.resetAll();
 
-    pub.setPreferences("network.proxy.socks", "192.168.0.10");
+    pub.setPreferences("network.proxy.socks", "10.152.152.10");
     pub.setPreferences("network.proxy.socks_port", 9102);
 
     pub.setPanelSettings(pub.strBundle.GetStringFromName("torbirdy.enabled.whonix"), "green");
