@@ -45,7 +45,6 @@ const TorBirdyPrefs = {
   "network.proxy.socks": "127.0.0.1",
   "network.proxy.socks_port": 9150,
   "network.proxy.socks_version": 5,
-  "network.proxy.no_proxies_on": "localhost, 127.0.0.1",
 
   // Set DNS proxying through SOCKS5.
   "network.proxy.socks_remote_dns": true,
@@ -156,6 +155,11 @@ const TorBirdyPrefs = {
   // https://lists.torproject.org/pipermail/tor-talk/2012-May/024395.html
   "mailnews.reply_header_type": 1,
   "mailnews.reply_header_authorwrote": "%s",
+  "mailnews.reply_header_authorwrotesingle": "#1:",
+  // Show Sender header in message pane (#10226).
+  // http://heise.de/-2044405
+  // https://bugzilla.mozilla.org/show_bug.cgi?id=332639
+  "mailnews.headers.showSender": true,
 
   /*
     Mail
@@ -214,7 +218,7 @@ const TorBirdyPrefs = {
                                               "--keyserver-options http-proxy=http://127.0.0.1:8118 ",
                                             
   // The default key server should be a hidden service and this is the only known one (it's part of the normal SKS network)
-  "extensions.enigmail.keyserver": "hkp://2eghzlv2wwcq7u7y.onion",
+  "extensions.enigmail.keyserver": "hkp://qdigse2yzvuglcix.onion",
 
   // Force GnuPG to use SHA512.
   "extensions.enigmail.mimeHashAlgorithm": 5,
@@ -297,7 +301,7 @@ const TorBirdyPrefs = {
 // when TorBirdy is initialized that should be preserved instead. When TorBirdy
 // is disabled or uninstalled, these preferences are restored to their original
 // value. All such preferences go here.
-const TorBirdyOldPrefs = [
+var TorBirdyOldPrefs = [
   "network.proxy.type",
   "network.proxy.ssl_port",
   "network.proxy.ssl",
@@ -409,7 +413,6 @@ TorBirdy.prototype = {
   },
 
   setPrefs: function() {
-    dump("Setting TorBirdy preferences\n");
     // If custom values are set for specific preferences, override the defaults with them.
     // For each preference, get the type and then set the property.
     for (var i = 0; i < this.customPrefs.length; i++) {
@@ -445,7 +448,10 @@ TorBirdy.prototype = {
   setAccountPrefs: function() {
     if (this.prefs.getBoolPref("extensions.torbirdy.first_run")) {
       // Save the current proxy settings so that the settings can be restored in case
-      // TorBirdy is uninstalled or disabled. (TorBirdyOldPrefs)
+      // TorBirdy is uninstalled or disabled. (TorBirdyOldPrefs).
+      // First copy TorBirdyPrefs to TorBirdyOldPrefs.
+      TorBirdyOldPrefs.push.apply(TorBirdyOldPrefs, Object.keys(TorBirdyPrefs));
+
       for (var i = 0; i < TorBirdyOldPrefs.length; i++) {
         var oldPref = TorBirdyOldPrefs[i];
         var type = this.prefs.getPrefType(oldPref);
@@ -485,26 +491,61 @@ TorBirdy.prototype = {
       }
 
       // For only the first run (after that the user can configure the account if need be):
-      //    Iterate through all accounts and disable automatic checking of emails.
+      //    save drafts for IMAP accounts locally
+      //    disable automatic checking of emails and enforce SSL/TLS
       var accounts = this.acctMgr.accounts;
 
-      // To maintain compatibility between Gecko 17+ and Gecko < 17.
       var allAccounts = [];
-      if (accounts.queryElementAt) {
-        for (var i = 0; i < accounts.length; i++) {
-          var account = accounts.queryElementAt(i, Ci.nsIMsgAccount).incomingServer;
-          allAccounts.push(account);
-        }
-      } else {
-        for (var i = 0; i < accounts.Count(); i++) {
-          var account = accounts.QueryElementAt(i, Ci.nsIMsgAccount).incomingServer;
-          allAccounts.push(account);
-        }
+      // To maintain compatibility between Gecko 17+ and Gecko < 17, find out
+      // which version we are on.
+      var newGecko = (accounts.queryElementAt) ? true : false;
+
+      var accountLength = newGecko ? accounts.length : accounts.Count();
+      for (var i = 0; i < accountLength; i++) {
+        var account = (newGecko) ?
+                      accounts.queryElementAt(i, Ci.nsIMsgAccount) :
+                      accounts.QueryElementAt(i, Ci.nsIMsgAccount);
+        allAccounts.push(account);
       }
 
+      // Save account settings for restoring later.
       for (var i = 0; i < allAccounts.length; i++) {
-        // Save account settings for restoring later.
-        var account = allAccounts[i];
+        var identities = allAccounts[i].identities;
+        var account = allAccounts[i].incomingServer;
+
+        // Get the locations of the Draft folder for all identities and save them.
+        // We only need to do this for IMAP accounts.
+        if (account.type === "imap") {
+          // Again ensure we maintain compatibility between different Gecko versions.
+          var identLength = newGecko ? identities.length : identities.Count();
+
+          for (var ident = 0; ident < identLength; ident++) {
+            var identity = (newGecko) ?
+                           identities.queryElementAt(ident, Ci.nsIMsgIdentity) :
+                           identities.QueryElementAt(ident, Ci.nsIMsgIdentity);
+
+            var key = identity.key;
+            // We need to restore the following preferences after we are uninstalled/disabled.
+            var restorePrefs = ["draft_folder", "drafts_folder_picker_mode"];
+
+            for (var p = 0; p < restorePrefs.length; p++) {
+              var pref = "mail.identity.%id%.".replace("%id%", key);
+              var prefName = pref + restorePrefs[p];
+              if (this.prefs.prefHasUserValue(prefName)) {
+                var typePref = this.prefs.getPrefType(prefName);
+                if (typePref === 32) {
+                  var currentPref = this.prefs.getCharPref(prefName);
+                  this.prefs.setCharPref(kRestoreBranch + prefName, currentPref);
+                }
+                TorBirdyOldPrefs.push(prefName);
+              }
+            }
+            // Now apply our setting where we set the Drafts folder to Local Folders.
+            // The user is free to change this as this setting is not enforced.
+            identity.draftFolder = "mailbox://nobody@Local%20Folders/Drafts";
+          }
+        }
+
         var key = account.key;
         var restorePrefs = ["check_new_mail", "login_at_startup",
                             "check_time", "download_on_biff",
